@@ -5,11 +5,11 @@
 from ..Element import Element
 import numpy as np
 import matplotlib.pyplot as plt
-import numpy as np
 import matplotlib.path as mpltPath
 
 
 class Element2D(Element):
+
     """Create a 2D element
 
     Args:
@@ -18,7 +18,7 @@ class Element2D(Element):
         gdl (np.ndarray): Degree of freedom matrix
     """
 
-    def __init__(self, coords: np.ndarray, _coords: np.ndarray, gdl: np.ndarray) -> None:
+    def __init__(self, coords: np.ndarray, _coords: np.ndarray, gdl: np.ndarray, **kargs) -> None:
         """Create a 2D element
 
         Args:
@@ -27,13 +27,19 @@ class Element2D(Element):
             gdl (np.ndarray): Degree of freedom matrix
         """
 
-        Element.__init__(self, coords, _coords, gdl)
+        Element.__init__(self, coords, _coords, gdl, **kargs)
         self._coordsg = np.array(
             self._coords.tolist()+[self._coords[0].tolist()])
+        for i, e in enumerate(self.borders):
+            delta = self._coordsg[i+1]-self._coordsg[i]
+            delta[0] *= -1
+            delta = delta[::-1]
+            delta = delta/np.linalg.norm(delta)
+            e.nx = delta[0]
+            e.ny = delta[1]
 
     def draw(self) -> None:
-        """Create a graph of element
-        """
+        """Create a graph of element"""
 
         _z = self.domain
         _x, _p = self.T(_z.T)
