@@ -16,7 +16,7 @@ class Element():
         border (bool): True if the element is part of the border domain of another element.
     """
 
-    def __init__(self, coords: np.ndarray, _coords: np.ndarray, gdl: np.ndarray, border: bool = False) -> None:
+    def __init__(self, coords: np.ndarray, _coords: np.ndarray, gdl: np.ndarray, border: bool = False, fast: bool = False) -> None:
         """Generates a generic element.
 
         Args:
@@ -30,6 +30,7 @@ class Element():
         self._coords = _coords
         self.border = border
         self.gdl = gdl
+        self.fast = fast
         self.gdlm = []
         for i in range(len(self.gdl)):
             for j in range(len(self.gdl[i])):
@@ -37,7 +38,7 @@ class Element():
         self.n = int(len(self.gdl)*len(self.gdl[0]))
         self.properties = {'load_x': [], 'load_y': []}
         self.intBorders = False
-        if not self.border:
+        if not self.border and not self.fast:
             # TODO Esta vaina debería eliminarse.
             # Los elementos no tienen porque guardar.
             # Sus matrices y vectores. Esto gasta memoria.
@@ -45,8 +46,26 @@ class Element():
             # eso se puede hacer directamente al calcular las matrices.
             self.Ke = np.zeros([self.n, self.n])
             self.Fe = np.zeros([self.n, 1])
-            self.Ue = np.zeros(self.gdl.shape)
             self.Qe = np.zeros([self.n, 1])
+        self.Ue = np.zeros(self.gdl.shape)
+
+    @classmethod
+    def description(self):
+        """Creates the elemetn description
+
+        Returns:
+            str: Description of the element
+        """
+        return ''
+
+    def restartMatrix(self):
+        """Sets all element matrices and vectors to 0 state
+        """
+        if not self.border:
+            self.Ke[:, :] = 0.0
+            self.Fe[:, :] = 0.0
+            self.Ue[:, :] = 0.0
+            self.Qe[:, :] = 0.0
 
     def T(self, z: np.ndarray) -> np.ndarray:
         """Give the global coordinates of given natural coordiantes over element
@@ -109,7 +128,7 @@ class Element():
         dpsis = self.dpsis(z).T
         return dpsis @ self.coords, dpsis
 
-    def giveSolution(self, SVSolution: bool = False) -> np.ndarray:
+    def giveSolution(self, SVSolution: bool = False, domain: str = 'domain') -> np.ndarray:
         """Calculate the interpolated solution over element domain
 
         Args:
@@ -121,6 +140,8 @@ class Element():
 
         # TODO hacer una comprobación de frontera para evitar errores
         _z = self.domain
+        if domain == 'gauss-points':
+            _z = self.Z
         _x, _p = self.T(_z.T)
         if SVSolution:
             j, dpz = self.J(_z.T)  # TODO Revisar con Reddy
