@@ -5,13 +5,15 @@ __author__ = "Arturo Rodriguez - da.rodriguezh@uniandes.edu.co"
 
 from .__version__ import __version__
 from .Elements import *
-from .Mesh import *
+from .Geometry import *
 from .Core import *
 from .Torsion2D import *
 from .EDO1D import *
 from .EulerBernoulliBeam import *
-from .PlaneStress import *
-from .PlaneStressNonLocal import *
-from .PlaneStrain import *
+from .Elasticity2D import *
+from .ODE2D import *
+from .NonLinealExample import *
 from .Heat1D import *
 from .Heat2D import *
+
+from .Elasticity3D import *
